==> jruby_9.3.9.0+ds.orig.tar.xz: jruby-9.3.9.0/test/mri/excludes/TestSetTraceFunc.rb <==
exclude :test_argument_error_on_bmethod, "needs investigation"
exclude :test_b_call_with_redo, "needs investigation"
exclude :test_break, "needs investigation"
exclude :test_break_with_rescue, "needs investigation"
exclude :test_c_call, "needs investigation"
exclude :test_call, "needs investigation"
exclude :test_class, "needs investigation"
exclude :test_const_missing, "needs investigation"
exclude :test_define_method_on_exception, "needs investigation"
exclude :test_define_method_on_return, "needs investigation"
exclude :test_fiber_switch, "needs investigation"
exclude :test_lineno_in_optimized_insn, "not implemented, jruby/jruby#6149"
exclude :test_method_missing, "needs investigation"
exclude :test_raise, "needs investigation"
exclude :test_rb_rescue, "needs investigation"
exclude :test_recursive, "needs investigation"
exclude :test_rescue_and_ensure_should_not_cause_b_return, "needs investigation"
exclude :test_return, "needs investigation"
exclude :test_return2, "needs investigation"
exclude :test_return_value_with_rescue, "needs investigation"
exclude :test_return_value_with_rescue_and_defined_methods, "needs investigation"
exclude :test_script_compiled, "not implemented, jruby/jruby#6149"
exclude :test_thread_add_trace_func, "hangs"
exclude :test_thread_trace, "needs investigation"
exclude :test_throwing_return_with_finish_frame, "needs investigation"
exclude :test_trace_defined_method, "needs investigation"
exclude :test_trace_point_at_return_when_exception, "needs investigation"
exclude :test_tracepoint, "needs investigation"
exclude :test_tracepoint_access_from_outside, "needs investigation"
exclude :test_tracepoint_b_return_with_lambda, "needs investigation"
exclude :test_tracepoint_b_return_with_next, "needs investigation"
exclude :test_tracepoint_block, "needs investigation"
exclude :test_tracepoint_callee_id, "needs investigation"
exclude :test_tracepoint_enable_target, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_enable_with_target_line, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_inspect, "needs investigation"
exclude :test_tracepoint_nested_enabled_with_target, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_raised_exception, "needs investigation"
exclude :test_tracepoint_return_value, "needs investigation"
exclude :test_tracepoint_parameters, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_thread, "needs investigation"

==> jruby_9.4.8.0+ds.orig.tar.xz: jruby-9.4.8.0/test/mri/excludes/TestSetTraceFunc.rb <==
exclude :test_argument_error_on_bmethod, "needs investigation"
exclude :test_b_call_with_redo, "needs investigation"
exclude :test_b_tracepoints_going_away, "needs investigation"
exclude :test_break, "needs investigation"
exclude :test_break_with_rescue, "needs investigation"
exclude :test_c_call, "needs investigation"
exclude :test_call, "needs investigation"
exclude :test_class, "needs investigation"
exclude :test_const_missing, "needs investigation"
exclude :test_define_method_on_exception, "needs investigation"
exclude :test_define_method_on_return, "needs investigation"
exclude :test_fiber_switch, "needs investigation"
exclude :test_lineno_in_optimized_insn, "not implemented, jruby/jruby#6149"
exclude :test_method_missing, "needs investigation"
exclude :test_raise, "needs investigation"
exclude :test_rb_rescue, "needs investigation"
exclude :test_recursive, "needs investigation"
exclude :test_rescue_and_ensure_should_not_cause_b_return, "needs investigation"
exclude :test_return, "needs investigation"
exclude :test_return2, "needs investigation"
exclude :test_return_bmethod_location, "needs investigation"
exclude :test_return_value_with_rescue, "needs investigation"
exclude :test_return_value_with_rescue_and_defined_methods, "needs investigation"
exclude :test_script_compiled, "not implemented, jruby/jruby#6149"
exclude :test_thread_add_trace_func, "hangs"
exclude :test_thread_trace, "needs investigation"
exclude :test_throwing_return_with_finish_frame, "needs investigation"
exclude :test_trace_defined_method, "needs investigation"
exclude :test_trace_point_at_return_when_exception, "needs investigation"
exclude :test_tracepoint, "needs investigation"
exclude :test_tracepoint_access_from_outside, "needs investigation"
exclude :test_tracepoint_attr, "needs investigation"
exclude :test_tracepoint_b_return_with_lambda, "needs investigation"
exclude :test_tracepoint_b_return_with_next, "needs investigation"
exclude :test_tracepoint_block, "needs investigation"
exclude :test_tracepoint_callee_id, "needs investigation"
exclude :test_tracepoint_enable_target, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_enable_with_target_line, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_inspect, "needs investigation"
exclude :test_tracepoint_memory_leak, "unsupported"
exclude :test_tracepoint_nested_enabled_with_target, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_opt_invokebuiltin_delegate_leave, "looking at iseq"
exclude :test_tracepoint_raised_exception, "needs investigation"
exclude :test_tracepoint_return_value, "needs investigation"
exclude :test_tracepoint_parameters, "not implemented, jruby/jruby#6149"
exclude :test_tracepoint_thread, "needs investigation"
exclude :"test_allow_reentry", "work in progress"
exclude :"test_enable_target_thread", "work in progress"
exclude :"test_non_local_return_across_multiple_define_methods", "work in progress"
exclude :"test_set_trace_func", "work in progress"
exclude :"test_stat_exists", "work in progress"
exclude :"test_target_different_bmethod_same_iseq", "work in progress"
exclude :"test_tracepoint_attr", "work in progress"
exclude :"test_tracepoint_disable", "work in progress"
exclude :"test_tracepoint_enable_with_target_line_two_times", "work in progress"
exclude :"test_tracepoint_opt_invokebuiltin_delegate_leave", "work in progress"
